| <!DOCTYPE html><html lang="en"><head><meta charset="utf-8"><meta name="viewport" content="width=device-width, initial-scale=1.0"><meta name="generator" content="rustdoc"><meta name="description" content="`Parser` struct provides the low-level API for navigating through the stream of tokens and constructing the parse tree. The actual parsing happens in the `grammar` module."><title>Parser in parser::parser - Rust</title><script>if(window.location.protocol!=="file:")document.head.insertAdjacentHTML("beforeend","SourceSerif4-Regular-6b053e98.ttf.woff2,FiraSans-Italic-81dc35de.woff2,FiraSans-Regular-0fe48ade.woff2,FiraSans-MediumItalic-ccf7e434.woff2,FiraSans-Medium-e1aa3f0a.woff2,SourceCodePro-Regular-8badfe75.ttf.woff2,SourceCodePro-Semibold-aa29a496.ttf.woff2".split(",").map(f=>`<link rel="preload" as="font" type="font/woff2"href="../../static.files/${f}">`).join(""))</script><link rel="stylesheet" href="../../static.files/normalize-9960930a.css"><link rel="stylesheet" href="../../static.files/rustdoc-77263533.css"><meta name="rustdoc-vars" data-root-path="../../" data-static-root-path="../../static.files/" data-current-crate="parser" data-themes="" data-resource-suffix="" data-rustdoc-version="1.94.0 (4a4ef493e 2026-03-02)" data-channel="1.94.0" data-search-js="search-9e2438ea.js" data-stringdex-js="stringdex-b897f86f.js" data-settings-js="settings-c38705f0.js" ><script src="../../static.files/storage-e2aeef58.js"></script><script defer src="sidebar-items.js"></script><script defer src="../../static.files/main-7bab91a1.js"></script><noscript><link rel="stylesheet" href="../../static.files/noscript-ffcac47a.css"></noscript><link rel="alternate icon" type="image/png" href="../../static.files/favicon-32x32-eab170b8.png"><link rel="icon" type="image/svg+xml" href="../../static.files/favicon-044be391.svg"></head><body class="rustdoc struct"><!--[if lte IE 11]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><rustdoc-topbar><h2><a href="#">Parser</a></h2></rustdoc-topbar><nav class="sidebar"><div class="sidebar-crate"><h2><a href="../../parser/index.html">parser</a><span class="version">0.0.0</span></h2></div><div class="sidebar-elems"><section id="rustdoc-toc"><h2 class="location"><a href="#">Parser</a></h2><h3><a href="#fields">Fields</a></h3><ul class="block structfield"><li><a href="#structfield.events" title="events">events</a></li><li><a href="#structfield.inp" title="inp">inp</a></li><li><a href="#structfield.pos" title="pos">pos</a></li><li><a href="#structfield.steps" title="steps">steps</a></li></ul><h3><a href="#implementations">Methods</a></h3><ul class="block method"><li><a href="#method.at" title="at">at</a></li><li><a href="#method.at_composite2" title="at_composite2">at_composite2</a></li><li><a href="#method.at_composite3" title="at_composite3">at_composite3</a></li><li><a href="#method.at_contextual_kw" title="at_contextual_kw">at_contextual_kw</a></li><li><a href="#method.at_ts" title="at_ts">at_ts</a></li><li><a href="#method.bump" title="bump">bump</a></li><li><a href="#method.bump_any" title="bump_any">bump_any</a></li><li><a href="#method.bump_remap" title="bump_remap">bump_remap</a></li><li><a href="#method.current" title="current">current</a></li><li><a href="#method.current_edition" title="current_edition">current_edition</a></li><li><a href="#method.do_bump" title="do_bump">do_bump</a></li><li><a href="#method.eat" title="eat">eat</a></li><li><a href="#method.eat_contextual_kw" title="eat_contextual_kw">eat_contextual_kw</a></li><li><a href="#method.err_and_bump" title="err_and_bump">err_and_bump</a></li><li><a href="#method.err_recover" title="err_recover">err_recover</a></li><li><a href="#method.error" title="error">error</a></li><li><a href="#method.expect" title="expect">expect</a></li><li><a href="#method.finish" title="finish">finish</a></li><li><a href="#method.new" title="new">new</a></li><li><a href="#method.nth" title="nth">nth</a></li><li><a href="#method.nth_at" title="nth_at">nth_at</a></li><li><a href="#method.nth_at_contextual_kw" title="nth_at_contextual_kw">nth_at_contextual_kw</a></li><li><a href="#method.push_event" title="push_event">push_event</a></li><li><a href="#method.split_float" title="split_float">split_float</a></li><li><a href="#method.start" title="start">start</a></li></ul><h3><a href="#synthetic-implementations">Auto Trait Implementations</a></h3><ul class="block synthetic-implementation"><li><a href="#impl-Freeze-for-Parser%3C't%3E" title="!Freeze">!Freeze</a></li><li><a href="#impl-RefUnwindSafe-for-Parser%3C't%3E" title="!RefUnwindSafe">!RefUnwindSafe</a></li><li><a href="#impl-Sync-for-Parser%3C't%3E" title="!Sync">!Sync</a></li><li><a href="#impl-Send-for-Parser%3C't%3E" title="Send">Send</a></li><li><a href="#impl-Unpin-for-Parser%3C't%3E" title="Unpin">Unpin</a></li><li><a href="#impl-UnwindSafe-for-Parser%3C't%3E" title="UnwindSafe">UnwindSafe</a></li></ul><h3><a href="#blanket-implementations">Blanket Implementations</a></h3><ul class="block blanket-implementation"><li><a href="#impl-Any-for-T" title="Any">Any</a></li><li><a href="#impl-Borrow%3CT%3E-for-T" title="Borrow<T>">Borrow<T></a></li><li><a href="#impl-BorrowMut%3CT%3E-for-T" title="BorrowMut<T>">BorrowMut<T></a></li><li><a href="#impl-From%3CT%3E-for-T" title="From<T>">From<T></a></li><li><a href="#impl-Instrument-for-T" title="Instrument">Instrument</a></li><li><a href="#impl-Into%3CU%3E-for-T" title="Into<U>">Into<U></a></li><li><a href="#impl-TryFrom%3CU%3E-for-T" title="TryFrom<U>">TryFrom<U></a></li><li><a href="#impl-TryInto%3CU%3E-for-T" title="TryInto<U>">TryInto<U></a></li><li><a href="#impl-WithSubscriber-for-T" title="WithSubscriber">WithSubscriber</a></li></ul></section><div id="rustdoc-modnav"><h2><a href="index.html">In parser::<wbr>parser</a></h2></div></div></nav><div class="sidebar-resizer" title="Drag to resize sidebar"></div><main><div class="width-limiter"><section id="main-content" class="content"><div class="main-heading"><div class="rustdoc-breadcrumbs"><a href="../index.html">parser</a>::<wbr><a href="index.html">parser</a></div><h1>Struct <span class="struct">Parser</span> <button id="copy-path" title="Copy item path to clipboard">Copy item path</button></h1><rustdoc-toolbar></rustdoc-toolbar><span class="sub-heading"><a class="src" href="../../src/parser/parser.rs.html#24-29">Source</a> </span></div><pre class="rust item-decl"><code>pub(crate) struct Parser<'t> { |
| inp: &'t <a class="struct" href="../struct.Input.html" title="struct parser::Input">Input</a>, |
| pos: <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.usize.html">usize</a>, |
| events: <a class="struct" href="https://doc.rust-lang.org/1.94.0/alloc/vec/struct.Vec.html" title="struct alloc::vec::Vec">Vec</a><<a class="enum" href="../event/enum.Event.html" title="enum parser::event::Event">Event</a>>, |
| steps: <a class="struct" href="https://doc.rust-lang.org/1.94.0/core/cell/struct.Cell.html" title="struct core::cell::Cell">Cell</a><<a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.u32.html">u32</a>>, |
| }</code></pre><details class="toggle top-doc" open><summary class="hideme"><span>Expand description</span></summary><div class="docblock"><p><code>Parser</code> struct provides the low-level API for |
| navigating through the stream of tokens and |
| constructing the parse tree. The actual parsing |
| happens in the <a href="../grammar/index.html" title="mod parser::grammar"><code>grammar</code></a> module.</p> |
| <p>However, the result of this <code>Parser</code> is not a real |
| tree, but rather a flat stream of events of the form |
| “start expression, consume number literal, |
| finish expression”. See <code>Event</code> docs for more.</p> |
| </div></details><h2 id="fields" class="fields section-header">Fields<a href="#fields" class="anchor"></a></h2><span id="structfield.inp" class="structfield section-header"><a href="#structfield.inp" class="anchor field"></a><code>inp: &'t <a class="struct" href="../struct.Input.html" title="struct parser::Input">Input</a></code></span><span id="structfield.pos" class="structfield section-header"><a href="#structfield.pos" class="anchor field"></a><code>pos: <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.usize.html">usize</a></code></span><span id="structfield.events" class="structfield section-header"><a href="#structfield.events" class="anchor field"></a><code>events: <a class="struct" href="https://doc.rust-lang.org/1.94.0/alloc/vec/struct.Vec.html" title="struct alloc::vec::Vec">Vec</a><<a class="enum" href="../event/enum.Event.html" title="enum parser::event::Event">Event</a>></code></span><span id="structfield.steps" class="structfield section-header"><a href="#structfield.steps" class="anchor field"></a><code>steps: <a class="struct" href="https://doc.rust-lang.org/1.94.0/core/cell/struct.Cell.html" title="struct core::cell::Cell">Cell</a><<a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.u32.html">u32</a>></code></span><h2 id="implementations" class="section-header">Implementations<a href="#implementations" class="anchor"></a></h2><div id="implementations-list"><details class="toggle implementors-toggle" open><summary><section id="impl-Parser%3C't%3E" class="impl"><a class="src rightside" href="../../src/parser/parser.rs.html#33-296">Source</a><a href="#impl-Parser%3C't%3E" class="anchor"></a><h3 class="code-header">impl<'t> <a class="struct" href="struct.Parser.html" title="struct parser::parser::Parser">Parser</a><'t></h3></section></summary><div class="impl-items"><section id="method.new" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#34-36">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.new" class="fn">new</a>(inp: &'t <a class="struct" href="../struct.Input.html" title="struct parser::Input">Input</a>) -> <a class="struct" href="struct.Parser.html" title="struct parser::parser::Parser">Parser</a><'t></h4></section><section id="method.finish" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#38-40">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.finish" class="fn">finish</a>(self) -> <a class="struct" href="https://doc.rust-lang.org/1.94.0/alloc/vec/struct.Vec.html" title="struct alloc::vec::Vec">Vec</a><<a class="enum" href="../event/enum.Event.html" title="enum parser::event::Event">Event</a>></h4></section><details class="toggle method-toggle" open><summary><section id="method.current" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#45-47">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.current" class="fn">current</a>(&self) -> <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a></h4></section></summary><div class="docblock"><p>Returns the kind of the current token. |
| If parser has already reached the end of input, |
| the special <code>EOF</code> kind is returned.</p> |
| </div></details><details class="toggle method-toggle" open><summary><section id="method.nth" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#51-59">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.nth" class="fn">nth</a>(&self, n: <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.usize.html">usize</a>) -> <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a></h4></section></summary><div class="docblock"><p>Lookahead operation: returns the kind of the next nth |
| token.</p> |
| </div></details><details class="toggle method-toggle" open><summary><section id="method.at" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#62-64">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.at" class="fn">at</a>(&self, kind: <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a>) -> <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.bool.html">bool</a></h4></section></summary><div class="docblock"><p>Checks if the current token is <code>kind</code>.</p> |
| </div></details><section id="method.nth_at" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#66-96">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.nth_at" class="fn">nth_at</a>(&self, n: <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.usize.html">usize</a>, kind: <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a>) -> <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.bool.html">bool</a></h4></section><details class="toggle method-toggle" open><summary><section id="method.eat" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#99-130">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.eat" class="fn">eat</a>(&mut self, kind: <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a>) -> <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.bool.html">bool</a></h4></section></summary><div class="docblock"><p>Consume the next token if <code>kind</code> matches.</p> |
| </div></details><section id="method.eat_contextual_kw" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#132-138">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.eat_contextual_kw" class="fn">eat_contextual_kw</a>(&mut self, kind: <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a>) -> <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.bool.html">bool</a></h4></section><section id="method.at_composite2" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#140-144">Source</a><h4 class="code-header">fn <a href="#method.at_composite2" class="fn">at_composite2</a>(&self, n: <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.usize.html">usize</a>, k1: <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a>, k2: <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a>) -> <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.bool.html">bool</a></h4></section><section id="method.at_composite3" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#146-152">Source</a><h4 class="code-header">fn <a href="#method.at_composite3" class="fn">at_composite3</a>( |
| &self, |
| n: <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.usize.html">usize</a>, |
| k1: <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a>, |
| k2: <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a>, |
| k3: <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a>, |
| ) -> <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.bool.html">bool</a></h4></section><details class="toggle method-toggle" open><summary><section id="method.at_ts" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#155-157">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.at_ts" class="fn">at_ts</a>(&self, kinds: <a class="struct" href="../token_set/struct.TokenSet.html" title="struct parser::token_set::TokenSet">TokenSet</a>) -> <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.bool.html">bool</a></h4></section></summary><div class="docblock"><p>Checks if the current token is in <code>kinds</code>.</p> |
| </div></details><details class="toggle method-toggle" open><summary><section id="method.at_contextual_kw" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#160-162">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.at_contextual_kw" class="fn">at_contextual_kw</a>(&self, kw: <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a>) -> <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.bool.html">bool</a></h4></section></summary><div class="docblock"><p>Checks if the current token is contextual keyword <code>kw</code>.</p> |
| </div></details><details class="toggle method-toggle" open><summary><section id="method.nth_at_contextual_kw" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#165-167">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.nth_at_contextual_kw" class="fn">nth_at_contextual_kw</a>(&self, n: <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.usize.html">usize</a>, kw: <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a>) -> <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.bool.html">bool</a></h4></section></summary><div class="docblock"><p>Checks if the nth token is contextual keyword <code>kw</code>.</p> |
| </div></details><details class="toggle method-toggle" open><summary><section id="method.start" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#172-176">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.start" class="fn">start</a>(&mut self) -> <a class="struct" href="struct.Marker.html" title="struct parser::parser::Marker">Marker</a></h4></section></summary><div class="docblock"><p>Starts a new node in the syntax tree. All nodes and tokens |
| consumed between the <code>start</code> and the corresponding <code>Marker::complete</code> |
| belong to the same node.</p> |
| </div></details><details class="toggle method-toggle" open><summary><section id="method.bump" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#179-181">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.bump" class="fn">bump</a>(&mut self, kind: <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a>)</h4></section></summary><div class="docblock"><p>Consume the next token. Panics if the parser isn’t currently at <code>kind</code>.</p> |
| </div></details><details class="toggle method-toggle" open><summary><section id="method.bump_any" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#184-190">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.bump_any" class="fn">bump_any</a>(&mut self)</h4></section></summary><div class="docblock"><p>Advances the parser by one token</p> |
| </div></details><details class="toggle method-toggle" open><summary><section id="method.split_float" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#193-219">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.split_float" class="fn">split_float</a>(&mut self, marker: <a class="struct" href="struct.Marker.html" title="struct parser::parser::Marker">Marker</a>) -> (<a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.bool.html">bool</a>, <a class="struct" href="struct.Marker.html" title="struct parser::parser::Marker">Marker</a>)</h4></section></summary><div class="docblock"><p>Advances the parser by one token</p> |
| </div></details><details class="toggle method-toggle" open><summary><section id="method.bump_remap" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#227-233">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.bump_remap" class="fn">bump_remap</a>(&mut self, kind: <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a>)</h4></section></summary><div class="docblock"><p>Advances the parser by one token, remapping its kind. |
| This is useful to create contextual keywords from |
| identifiers. For example, the lexer creates a <code>union</code> |
| <em>identifier</em> token, but the parser remaps it to the |
| <code>union</code> keyword, and keyword is what ends up in the |
| final tree.</p> |
| </div></details><details class="toggle method-toggle" open><summary><section id="method.error" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#239-242">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.error" class="fn">error</a><T: <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/convert/trait.Into.html" title="trait core::convert::Into">Into</a><<a class="struct" href="https://doc.rust-lang.org/1.94.0/alloc/string/struct.String.html" title="struct alloc::string::String">String</a>>>(&mut self, message: T)</h4></section></summary><div class="docblock"><p>Emit error with the <code>message</code> |
| FIXME: this should be much more fancy and support |
| structured errors with spans and notes, like rustc |
| does.</p> |
| </div></details><details class="toggle method-toggle" open><summary><section id="method.expect" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#246-252">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.expect" class="fn">expect</a>(&mut self, kind: <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a>) -> <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.bool.html">bool</a></h4></section></summary><div class="docblock"><p>Consume the next token if it is <code>kind</code> or emit an error |
| otherwise.</p> |
| </div></details><details class="toggle method-toggle" open><summary><section id="method.err_and_bump" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#255-260">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.err_and_bump" class="fn">err_and_bump</a>(&mut self, message: &<a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.str.html">str</a>)</h4></section></summary><div class="docblock"><p>Create an error node and consume the next token.</p> |
| </div></details><details class="toggle method-toggle" open><summary><section id="method.err_recover" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#265-281">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.err_recover" class="fn">err_recover</a>(&mut self, message: &<a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.str.html">str</a>, recovery: <a class="struct" href="../token_set/struct.TokenSet.html" title="struct parser::token_set::TokenSet">TokenSet</a>) -> <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.bool.html">bool</a></h4></section></summary><div class="docblock"><p>Create an error node and consume the next token unless it is in the recovery set.</p> |
| <p>Returns true if recovery kicked in.</p> |
| </div></details><section id="method.do_bump" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#283-287">Source</a><h4 class="code-header">fn <a href="#method.do_bump" class="fn">do_bump</a>(&mut self, kind: <a class="enum" href="../enum.SyntaxKind.html" title="enum parser::SyntaxKind">SyntaxKind</a>, n_raw_tokens: <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.u8.html">u8</a>)</h4></section><section id="method.push_event" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#289-291">Source</a><h4 class="code-header">fn <a href="#method.push_event" class="fn">push_event</a>(&mut self, event: <a class="enum" href="../event/enum.Event.html" title="enum parser::event::Event">Event</a>)</h4></section><section id="method.current_edition" class="method"><a class="src rightside" href="../../src/parser/parser.rs.html#293-295">Source</a><h4 class="code-header">pub(crate) fn <a href="#method.current_edition" class="fn">current_edition</a>(&self) -> <a class="enum" href="../enum.Edition.html" title="enum parser::Edition">Edition</a></h4></section></div></details></div><h2 id="synthetic-implementations" class="section-header">Auto Trait Implementations<a href="#synthetic-implementations" class="anchor"></a></h2><div id="synthetic-implementations-list"><section id="impl-Freeze-for-Parser%3C't%3E" class="impl"><a href="#impl-Freeze-for-Parser%3C't%3E" class="anchor"></a><h3 class="code-header">impl<'t> !<a class="trait" href="https://doc.rust-lang.org/1.94.0/core/marker/trait.Freeze.html" title="trait core::marker::Freeze">Freeze</a> for <a class="struct" href="struct.Parser.html" title="struct parser::parser::Parser">Parser</a><'t></h3></section><section id="impl-RefUnwindSafe-for-Parser%3C't%3E" class="impl"><a href="#impl-RefUnwindSafe-for-Parser%3C't%3E" class="anchor"></a><h3 class="code-header">impl<'t> !<a class="trait" href="https://doc.rust-lang.org/1.94.0/core/panic/unwind_safe/trait.RefUnwindSafe.html" title="trait core::panic::unwind_safe::RefUnwindSafe">RefUnwindSafe</a> for <a class="struct" href="struct.Parser.html" title="struct parser::parser::Parser">Parser</a><'t></h3></section><section id="impl-Send-for-Parser%3C't%3E" class="impl"><a href="#impl-Send-for-Parser%3C't%3E" class="anchor"></a><h3 class="code-header">impl<'t> <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/marker/trait.Send.html" title="trait core::marker::Send">Send</a> for <a class="struct" href="struct.Parser.html" title="struct parser::parser::Parser">Parser</a><'t></h3></section><section id="impl-Sync-for-Parser%3C't%3E" class="impl"><a href="#impl-Sync-for-Parser%3C't%3E" class="anchor"></a><h3 class="code-header">impl<'t> !<a class="trait" href="https://doc.rust-lang.org/1.94.0/core/marker/trait.Sync.html" title="trait core::marker::Sync">Sync</a> for <a class="struct" href="struct.Parser.html" title="struct parser::parser::Parser">Parser</a><'t></h3></section><section id="impl-Unpin-for-Parser%3C't%3E" class="impl"><a href="#impl-Unpin-for-Parser%3C't%3E" class="anchor"></a><h3 class="code-header">impl<'t> <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/marker/trait.Unpin.html" title="trait core::marker::Unpin">Unpin</a> for <a class="struct" href="struct.Parser.html" title="struct parser::parser::Parser">Parser</a><'t></h3></section><section id="impl-UnwindSafe-for-Parser%3C't%3E" class="impl"><a href="#impl-UnwindSafe-for-Parser%3C't%3E" class="anchor"></a><h3 class="code-header">impl<'t> <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/panic/unwind_safe/trait.UnwindSafe.html" title="trait core::panic::unwind_safe::UnwindSafe">UnwindSafe</a> for <a class="struct" href="struct.Parser.html" title="struct parser::parser::Parser">Parser</a><'t></h3></section></div><h2 id="blanket-implementations" class="section-header">Blanket Implementations<a href="#blanket-implementations" class="anchor"></a></h2><div id="blanket-implementations-list"><details class="toggle implementors-toggle"><summary><section id="impl-Any-for-T" class="impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/any.rs.html#138">Source</a><a href="#impl-Any-for-T" class="anchor"></a><h3 class="code-header">impl<T> <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/any/trait.Any.html" title="trait core::any::Any">Any</a> for T<div class="where">where |
| T: 'static + ?<a class="trait" href="https://doc.rust-lang.org/1.94.0/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a>,</div></h3></section></summary><div class="impl-items"><details class="toggle method-toggle" open><summary><section id="method.type_id" class="method trait-impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/any.rs.html#139">Source</a><a href="#method.type_id" class="anchor"></a><h4 class="code-header">fn <a href="https://doc.rust-lang.org/1.94.0/core/any/trait.Any.html#tymethod.type_id" class="fn">type_id</a>(&self) -> <a class="struct" href="https://doc.rust-lang.org/1.94.0/core/any/struct.TypeId.html" title="struct core::any::TypeId">TypeId</a></h4></section></summary><div class='docblock'>Gets the <code>TypeId</code> of <code>self</code>. <a href="https://doc.rust-lang.org/1.94.0/core/any/trait.Any.html#tymethod.type_id">Read more</a></div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-Borrow%3CT%3E-for-T" class="impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/borrow.rs.html#212">Source</a><a href="#impl-Borrow%3CT%3E-for-T" class="anchor"></a><h3 class="code-header">impl<T> <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/borrow/trait.Borrow.html" title="trait core::borrow::Borrow">Borrow</a><T> for T<div class="where">where |
| T: ?<a class="trait" href="https://doc.rust-lang.org/1.94.0/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a>,</div></h3></section></summary><div class="impl-items"><details class="toggle method-toggle" open><summary><section id="method.borrow" class="method trait-impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/borrow.rs.html#214">Source</a><a href="#method.borrow" class="anchor"></a><h4 class="code-header">fn <a href="https://doc.rust-lang.org/1.94.0/core/borrow/trait.Borrow.html#tymethod.borrow" class="fn">borrow</a>(&self) -> <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.reference.html">&T</a></h4></section></summary><div class='docblock'>Immutably borrows from an owned value. <a href="https://doc.rust-lang.org/1.94.0/core/borrow/trait.Borrow.html#tymethod.borrow">Read more</a></div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-BorrowMut%3CT%3E-for-T" class="impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/borrow.rs.html#221">Source</a><a href="#impl-BorrowMut%3CT%3E-for-T" class="anchor"></a><h3 class="code-header">impl<T> <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/borrow/trait.BorrowMut.html" title="trait core::borrow::BorrowMut">BorrowMut</a><T> for T<div class="where">where |
| T: ?<a class="trait" href="https://doc.rust-lang.org/1.94.0/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a>,</div></h3></section></summary><div class="impl-items"><details class="toggle method-toggle" open><summary><section id="method.borrow_mut" class="method trait-impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/borrow.rs.html#222">Source</a><a href="#method.borrow_mut" class="anchor"></a><h4 class="code-header">fn <a href="https://doc.rust-lang.org/1.94.0/core/borrow/trait.BorrowMut.html#tymethod.borrow_mut" class="fn">borrow_mut</a>(&mut self) -> <a class="primitive" href="https://doc.rust-lang.org/1.94.0/std/primitive.reference.html">&mut T</a></h4></section></summary><div class='docblock'>Mutably borrows from an owned value. <a href="https://doc.rust-lang.org/1.94.0/core/borrow/trait.BorrowMut.html#tymethod.borrow_mut">Read more</a></div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-From%3CT%3E-for-T" class="impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/convert/mod.rs.html#785">Source</a><a href="#impl-From%3CT%3E-for-T" class="anchor"></a><h3 class="code-header">impl<T> <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/convert/trait.From.html" title="trait core::convert::From">From</a><T> for T</h3></section></summary><div class="impl-items"><details class="toggle method-toggle" open><summary><section id="method.from" class="method trait-impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/convert/mod.rs.html#788">Source</a><a href="#method.from" class="anchor"></a><h4 class="code-header">fn <a href="https://doc.rust-lang.org/1.94.0/core/convert/trait.From.html#tymethod.from" class="fn">from</a>(t: T) -> T</h4></section></summary><div class="docblock"><p>Returns the argument unchanged.</p> |
| </div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-Instrument-for-T" class="impl"><a href="#impl-Instrument-for-T" class="anchor"></a><h3 class="code-header">impl<T> Instrument for T</h3></section></summary><div class="impl-items"><details class="toggle method-toggle" open><summary><section id="method.instrument" class="method trait-impl"><a href="#method.instrument" class="anchor"></a><h4 class="code-header">fn <a class="fn">instrument</a>(self, span: Span) -> Instrumented<Self></h4></section></summary><div class='docblock'>Instruments this type with the provided [<code>Span</code>], returning an |
| <code>Instrumented</code> wrapper. <a>Read more</a></div></details><details class="toggle method-toggle" open><summary><section id="method.in_current_span" class="method trait-impl"><a href="#method.in_current_span" class="anchor"></a><h4 class="code-header">fn <a class="fn">in_current_span</a>(self) -> Instrumented<Self></h4></section></summary><div class='docblock'>Instruments this type with the <a href="super::Span::current()">current</a> <a href="crate::Span"><code>Span</code></a>, returning an |
| <code>Instrumented</code> wrapper. <a>Read more</a></div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-Into%3CU%3E-for-T" class="impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/convert/mod.rs.html#767-769">Source</a><a href="#impl-Into%3CU%3E-for-T" class="anchor"></a><h3 class="code-header">impl<T, U> <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/convert/trait.Into.html" title="trait core::convert::Into">Into</a><U> for T<div class="where">where |
| U: <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/convert/trait.From.html" title="trait core::convert::From">From</a><T>,</div></h3></section></summary><div class="impl-items"><details class="toggle method-toggle" open><summary><section id="method.into" class="method trait-impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/convert/mod.rs.html#777">Source</a><a href="#method.into" class="anchor"></a><h4 class="code-header">fn <a href="https://doc.rust-lang.org/1.94.0/core/convert/trait.Into.html#tymethod.into" class="fn">into</a>(self) -> U</h4></section></summary><div class="docblock"><p>Calls <code>U::from(self)</code>.</p> |
| <p>That is, this conversion is whatever the implementation of |
| <code><a href="https://doc.rust-lang.org/1.94.0/core/convert/trait.From.html" title="trait core::convert::From">From</a><T> for U</code> chooses to do.</p> |
| </div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-TryFrom%3CU%3E-for-T" class="impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/convert/mod.rs.html#827-829">Source</a><a href="#impl-TryFrom%3CU%3E-for-T" class="anchor"></a><h3 class="code-header">impl<T, U> <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a><U> for T<div class="where">where |
| U: <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/convert/trait.Into.html" title="trait core::convert::Into">Into</a><T>,</div></h3></section></summary><div class="impl-items"><details class="toggle" open><summary><section id="associatedtype.Error-1" class="associatedtype trait-impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/convert/mod.rs.html#831">Source</a><a href="#associatedtype.Error-1" class="anchor"></a><h4 class="code-header">type <a href="https://doc.rust-lang.org/1.94.0/core/convert/trait.TryFrom.html#associatedtype.Error" class="associatedtype">Error</a> = <a class="enum" href="https://doc.rust-lang.org/1.94.0/core/convert/enum.Infallible.html" title="enum core::convert::Infallible">Infallible</a></h4></section></summary><div class='docblock'>The type returned in the event of a conversion error.</div></details><details class="toggle method-toggle" open><summary><section id="method.try_from" class="method trait-impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/convert/mod.rs.html#834">Source</a><a href="#method.try_from" class="anchor"></a><h4 class="code-header">fn <a href="https://doc.rust-lang.org/1.94.0/core/convert/trait.TryFrom.html#tymethod.try_from" class="fn">try_from</a>(value: U) -> <a class="enum" href="https://doc.rust-lang.org/1.94.0/core/result/enum.Result.html" title="enum core::result::Result">Result</a><T, <T as <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a><U>>::<a class="associatedtype" href="https://doc.rust-lang.org/1.94.0/core/convert/trait.TryFrom.html#associatedtype.Error" title="type core::convert::TryFrom::Error">Error</a>></h4></section></summary><div class='docblock'>Performs the conversion.</div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-TryInto%3CU%3E-for-T" class="impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/convert/mod.rs.html#811-813">Source</a><a href="#impl-TryInto%3CU%3E-for-T" class="anchor"></a><h3 class="code-header">impl<T, U> <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/convert/trait.TryInto.html" title="trait core::convert::TryInto">TryInto</a><U> for T<div class="where">where |
| U: <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a><T>,</div></h3></section></summary><div class="impl-items"><details class="toggle" open><summary><section id="associatedtype.Error" class="associatedtype trait-impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/convert/mod.rs.html#815">Source</a><a href="#associatedtype.Error" class="anchor"></a><h4 class="code-header">type <a href="https://doc.rust-lang.org/1.94.0/core/convert/trait.TryInto.html#associatedtype.Error" class="associatedtype">Error</a> = <U as <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a><T>>::<a class="associatedtype" href="https://doc.rust-lang.org/1.94.0/core/convert/trait.TryFrom.html#associatedtype.Error" title="type core::convert::TryFrom::Error">Error</a></h4></section></summary><div class='docblock'>The type returned in the event of a conversion error.</div></details><details class="toggle method-toggle" open><summary><section id="method.try_into" class="method trait-impl"><a class="src rightside" href="https://doc.rust-lang.org/1.94.0/src/core/convert/mod.rs.html#818">Source</a><a href="#method.try_into" class="anchor"></a><h4 class="code-header">fn <a href="https://doc.rust-lang.org/1.94.0/core/convert/trait.TryInto.html#tymethod.try_into" class="fn">try_into</a>(self) -> <a class="enum" href="https://doc.rust-lang.org/1.94.0/core/result/enum.Result.html" title="enum core::result::Result">Result</a><U, <U as <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a><T>>::<a class="associatedtype" href="https://doc.rust-lang.org/1.94.0/core/convert/trait.TryFrom.html#associatedtype.Error" title="type core::convert::TryFrom::Error">Error</a>></h4></section></summary><div class='docblock'>Performs the conversion.</div></details></div></details><details class="toggle implementors-toggle"><summary><section id="impl-WithSubscriber-for-T" class="impl"><a href="#impl-WithSubscriber-for-T" class="anchor"></a><h3 class="code-header">impl<T> WithSubscriber for T</h3></section></summary><div class="impl-items"><details class="toggle method-toggle" open><summary><section id="method.with_subscriber" class="method trait-impl"><a href="#method.with_subscriber" class="anchor"></a><h4 class="code-header">fn <a class="fn">with_subscriber</a><S>(self, subscriber: S) -> WithDispatch<Self><div class="where">where |
| S: <a class="trait" href="https://doc.rust-lang.org/1.94.0/core/convert/trait.Into.html" title="trait core::convert::Into">Into</a><Dispatch>,</div></h4></section></summary><div class='docblock'>Attaches the provided <a href="super::Subscriber"><code>Subscriber</code></a> to this type, returning a |
| [<code>WithDispatch</code>] wrapper. <a>Read more</a></div></details><details class="toggle method-toggle" open><summary><section id="method.with_current_subscriber" class="method trait-impl"><a href="#method.with_current_subscriber" class="anchor"></a><h4 class="code-header">fn <a class="fn">with_current_subscriber</a>(self) -> WithDispatch<Self></h4></section></summary><div class='docblock'>Attaches the current <a href="crate::dispatcher#setting-the-default-subscriber">default</a> <a href="super::Subscriber"><code>Subscriber</code></a> to this type, returning a |
| [<code>WithDispatch</code>] wrapper. <a>Read more</a></div></details></div></details></div></section></div></main></body></html> |